@@ -73,7 +73,7 @@
 //
 
 #define PROJECT_NAME "QDevelop"
-#define VERSION "0.25"
+#define VERSION "0.27"
 
 MainImpl::MainImpl(QWidget * parent)
         : QMainWindow(parent)
@@ -91,6 +91,7 @@ MainImpl::MainImpl(QWidget * parent)
     m_tabSpaces = false;
     m_autoCompletion = true;
     m_autobrackets = true;
+    m_autocomments = true;
     m_match = true;
     m_highlightCurrentLine = true;
     m_backgroundColor = Qt::white;
@@ -105,6 +106,7 @@ MainImpl::MainImpl(QWidget * parent)
     m_completion = 0;
     m_projectsDirectory = QDir::homePath();
     m_closeButtonInTabs = false;
+    m_wordWrap = false;
     m_assistant = 0;
     m_designer = 0;
     crossButton = 0;
@@ -117,8 +119,10 @@ MainImpl::MainImpl(QWidget * parent)
     m_buildQtDatabaseAsked = false;
     m_displayEditorToolbars = true;
     m_displayWhiteSpaces = true;
+    m_rightMarginLine = 80;
     m_automaticCompilation = true;
-
+    m_hideFindReplace = 10;
+    m_smartClick = true;
     //
     m_formatPreprocessorText.setForeground(QColor(0,128,0));
     m_formatQtText.setForeground(Qt::blue);
@@ -137,8 +141,11 @@ MainImpl::MainImpl(QWidget * parent)
     actionOtherFile->setVisible(false);
     toolBarEdit->addAction(actionOtherFile);
 
-#ifdef WIN32
+#ifdef Q_WS_WIN
     m_font = QFont("Courier New", 10);
+#elif defined Q_WS_MACX
+    m_font = QFont("Monaco", 12);
+    setUnifiedTitleAndToolBarOnMac(false);
 #else
     m_font = QFont("Monospace", 10);
 #endif
@@ -161,18 +168,21 @@ MainImpl::MainImpl(QWidget * parent)
     treeClasses->setColumnCount(1);
     treeClasses->setHeaderLabels(QStringList(""));
     treeClasses->setMainImpl( this );
-    //
-    menuView->addSeparator();
-    menuView->addAction(dockExplorer->toggleViewAction());
-    menuView->addAction(dockOutputs->toggleViewAction());
-    menuView->addAction(dockCallsStack->toggleViewAction());
-    menuView->addAction(dockRegisters->toggleViewAction());
-    menuView->addSeparator();
-    //
+
+    menuDockWindows->addAction(dockFiles->toggleViewAction() );
+    menuDockWindows->addAction(dockClasses->toggleViewAction() );
+    menuDockWindows->addAction(dockBuild->toggleViewAction() );
+    menuDockWindows->addAction(dockOutputs->toggleViewAction() );
+    menuDockWindows->addAction(dockVariables->toggleViewAction() );
+    menuDockWindows->addAction(dockOtherVariables->toggleViewAction() );
+    menuDockWindows->addAction(dockFindInFiles->toggleViewAction() );
+    menuDockWindows->addAction(dockRegisters->toggleViewAction() );
+    menuDockWindows->addAction(dockCallsStack->toggleViewAction() );
+
     menuToolbar->addAction(toolBarFiles->toggleViewAction());
     menuToolbar->addAction(toolBarEdit->toggleViewAction());
     menuToolbar->addAction(toolBarBuild->toggleViewAction());
-    //
+
     for (int i = 0; i < maxRecentsFiles; ++i)
     {
         actionsRecentsFiles[i] = new QAction(this);
@@ -192,18 +202,14 @@ MainImpl::MainImpl(QWidget * parent)
     updateActionsRecentsProjects();
     createConnections();
     setMouseTracking( true );
-    //
-    dockExplorer->setFloating( false );
-    dockOutputs->setFloating( false );
-    dockCallsStack->setFloating( false );
-    //
-    dockExplorer->setAllowedAreas(Qt::LeftDockWidgetArea | Qt::RightDockWidgetArea);
-    addDockWidget(Qt::LeftDockWidgetArea, dockExplorer);
-    //
+
+    logBuild->zoomOut( 1 );
+    logDebug->zoomOut( 1 );
     m_stack = new StackImpl(this, callStacks);
-    //
     treeClasses->setCtagsName( m_ctagsName );
     logBuild->setMainImpl( this );
+    
+    on_actionFullDocksView_triggered();
 }
 //
 MainImpl::~MainImpl()
@@ -231,12 +237,12 @@ Editor * MainImpl::currentEditor()
 	int currentIndex = m_tabEditors->currentIndex();
 	if( currentIndex != -1 )
 		editor = (Editor*) (m_tabEditors->widget( currentIndex ));
-    return editor;
+	return editor;
 }
 
 Editor * MainImpl::givenEditor(int i)
 {
-    return (Editor*) (m_tabEditors->widget(i));
+	return qobject_cast<Editor*> (m_tabEditors->widget(i));
 }
 
 //
@@ -269,7 +275,8 @@ void MainImpl::gotoFileInProject(QString& filename)
     if ( !m_projectManager )
         return;
 
-    tabExplorer->setCurrentIndex(0);
+    dockFiles->show();
+    dockFiles->raise();
     m_projectManager->setCurrentItem(filename);
 }
 //
@@ -313,6 +320,9 @@ void MainImpl::createConnections()
     connect(actionSaveFileAs, SIGNAL(triggered()), this, SLOT(slotSaveFileAs()) );
     connect(actionCompile, SIGNAL(triggered()), this, SLOT(slotCompile()) );
     connect(actionBuild, SIGNAL(triggered()), this, SLOT(slotBuild()) );
+    connect(actionRelease_mode, SIGNAL(triggered()), this, SLOT(slotBuildRelease()) );
+    connect(actionDebug_mode, SIGNAL(triggered()), this, SLOT(slotBuildDebug()) );
+    connect(action_Forget_last_used_mode, SIGNAL(triggered()), this, SLOT(slotForgetBuildMode()) );
     connect(actionRebuild, SIGNAL(triggered()), this, SLOT(slotRebuild()) );
     connect(actionQmake, SIGNAL(triggered()), this, SLOT(slotQmake()) );
     connect(actionStopBuild, SIGNAL(triggered()), this, SLOT(slotStopBuild()) );
@@ -418,6 +428,9 @@ void MainImpl::createConnections()
     m_buildingGroup->addAction( actionStepInto );
     m_buildingGroup->addAction( actionStepOver );
     m_buildingGroup->addAction( actionStepOut );
+    m_buildingGroup->addAction( actionDebug_mode );
+    m_buildingGroup->addAction( actionRelease_mode );
+    m_buildingGroup->addAction( action_Forget_last_used_mode );
 }
 //
 void MainImpl::slotShortcuts()
@@ -608,11 +621,11 @@ void MainImpl::slotOptions()
                                            m_formatPreprocessorText, m_formatQtText, m_formatSingleComments,
                                            m_formatMultilineComments, m_formatQuotationText, m_formatMethods,
                                            m_formatKeywords, m_autoMaskDocks, m_endLine, m_tabSpaces, m_autoCompletion,
-                                           m_backgroundColor, m_promptBeforeQuit, m_highlightCurrentLine, m_currentLineColor, m_autobrackets,
+                                           m_backgroundColor, m_promptBeforeQuit, m_highlightCurrentLine, m_currentLineColor, m_autobrackets, m_autocomments,
                                            m_showTreeClasses, m_intervalUpdatingClasses, m_projectsDirectory, m_match, m_matchingColor,
                                            m_closeButtonInTabs, m_pluginsDirectory, m_makeOptions, m_mibCodec,
-                                           m_includeDirectory, m_displayEditorToolbars, m_displayWhiteSpaces, m_documentationDirectory,
-                                           m_textColor, m_automaticCompilation
+                                           m_includeDirectory, m_displayEditorToolbars, m_displayWhiteSpaces, m_rightMarginLine, m_documentationDirectory,
+                                           m_textColor, m_automaticCompilation, m_wordWrap, m_hideFindReplace, m_smartClick
      );
 
     if ( options->exec() == QDialog::Accepted )
@@ -633,6 +646,9 @@ void MainImpl::slotOptions()
         m_tabSpaces = options->tabSpaces->isChecked();
         m_autoCompletion = options->completion->isChecked();
         m_autobrackets = options->brackets->isChecked();
+        // Divius: comments autoclose
+        m_autocomments = options->comments->isChecked();
+        //
         m_match = options->match->isChecked();
         m_highlightCurrentLine = options->groupHighlightCurrentLine->isChecked();
         m_promptBeforeQuit = options->promptBeforeQuit->isChecked();
@@ -658,6 +674,16 @@ void MainImpl::slotOptions()
         m_mibCodec = options->mib();
         m_displayEditorToolbars = options->showEditorToolbars->isChecked();
         m_displayWhiteSpaces = options->displayWhiteSpaces->isChecked();
+        if (options->rightMarginLine->isChecked())
+            m_rightMarginLine = options->rightMarginPos->value();
+        else
+            m_rightMarginLine = 0;
+        m_wordWrap = options->wordwrap->isChecked();
+        if (options->hideFindReplace->isChecked())
+        	m_hideFindReplace = options->findReplaceDelay->value();
+        else
+        	m_hideFindReplace = 0;
+        m_smartClick = options->smartClick->isChecked();
 
         slotUpdateOtherFileActions();
         foreach(Editor *editor, allEditors() )
@@ -680,7 +706,9 @@ void MainImpl::slotOptions()
             editor->setCurrentLineColor( m_currentLineColor );
             editor->setMatchingColor( m_matchingColor );
             editor->setAutobrackets( m_autobrackets );
+            editor->setAutocomments( m_autocomments );
             editor->setShowWhiteSpaces( m_displayWhiteSpaces );
+            editor->setRightMargin( m_rightMarginLine );
             editor->displayEditorToolbar( m_displayEditorToolbars );
             editor->setSyntaxColors
             (
@@ -692,13 +720,18 @@ void MainImpl::slotOptions()
                 m_formatMethods,
                 m_formatKeywords
             );
+            editor->setWordWrap(m_wordWrap);
+            editor->setHideFindReplace(m_hideFindReplace);
+            editor->smartClick = m_smartClick;
         }
-        tabExplorer->setTabEnabled( 1, m_showTreeClasses );
+	/* TODO
         if (!m_showTreeClasses) //ToolsOptions/General
             tabExplorer->setTabToolTip( 1, tr("Classes explorer is disabled, please enable it in the Options dialog") );
         else
             tabExplorer->setTabToolTip( 1, "" );
-	    m_assistant->setdocumentationDirectory( m_documentationDirectory );
+	*/
+	 
+	m_assistant->setdocumentationDirectory( m_documentationDirectory );
         QApplication::restoreOverrideCursor();
     }
     delete options;
@@ -724,6 +757,9 @@ void MainImpl::saveINI()
     settings.setValue("m_promptBeforeQuit", m_promptBeforeQuit);
     settings.setValue("m_autoCompletion", m_autoCompletion);
     settings.setValue("m_autobrackets", m_autobrackets);
+    // Divius: comments autoclose
+    settings.setValue("m_autocomments", m_autocomments);
+    //
     settings.setValue("m_closeButtonInTabs", m_closeButtonInTabs);
     settings.setValue("m_match", m_match);
     settings.setValue("m_highlightCurrentLine", m_highlightCurrentLine);
@@ -750,7 +786,11 @@ void MainImpl::saveINI()
     settings.setValue("m_formatKeywords", m_formatKeywords.foreground().color().name());
     settings.setValue("m_displayEditorToolbars", m_displayEditorToolbars);
     settings.setValue("m_displayWhiteSpaces", m_displayWhiteSpaces);
+    settings.setValue("m_rightMarginLine", m_rightMarginLine);
     settings.setValue("editorMode", actionEditor_mode->isChecked() );
+    settings.setValue("m_wordWrap", m_wordWrap);
+    settings.setValue("m_hideFindReplace", m_hideFindReplace);
+    settings.setValue("m_smartClick", m_smartClick);
     settings.endGroup();
 
     // Save shortcuts
@@ -775,7 +815,6 @@ void MainImpl::saveINI()
     }
     settings.endGroup();
 
-    //
     //if ( !m_projectManager )
     //return;
 
@@ -799,7 +838,6 @@ void MainImpl::saveINI()
     settings.setValue("fullscreen", isFullScreen());
     settings.setValue("geometry", saveGeometry()); // Window geometry and state (only needed for Windows!).
     settings.setValue("state", saveState()); // Toolbar and DockWidget state.
-    settings.setValue("tabExplorer", tabExplorer->currentIndex());
     settings.endGroup();
 
 	settings.beginGroup("editormode");
@@ -839,6 +877,9 @@ QString MainImpl::loadINI()
     m_autoIndent = settings.value("m_autoIndent", m_autoIndent).toBool();
     m_autoCompletion = settings.value("m_autoCompletion", m_autoCompletion).toBool();
     m_autobrackets = settings.value("m_autobrackets", m_autobrackets).toBool();
+    // Divius: comments autoclose
+    m_autocomments = settings.value("m_autocomments", m_autocomments).toBool();
+    //
     m_selectionBorder = settings.value("m_selectionBorder", m_selectionBorder).toBool();
     m_saveBeforeBuild = settings.value("m_saveBeforeBuild", m_saveBeforeBuild).toBool();
     m_restoreOnStart = settings.value("m_restoreOnStart", m_restoreOnStart).toBool();
@@ -863,6 +904,10 @@ QString MainImpl::loadINI()
     m_displayEditorToolbars = settings.value("m_displayEditorToolbars", m_displayEditorToolbars).toBool();
     slotUpdateOtherFileActions();
     m_displayWhiteSpaces = settings.value("m_displayWhiteSpaces", m_displayWhiteSpaces).toBool();
+    m_rightMarginLine = settings.value("m_rightMarginLine", m_rightMarginLine).toInt();
+    m_wordWrap = settings.value("m_wordWrap", m_wordWrap).toBool();
+    m_hideFindReplace = settings.value("m_hideFindReplace", m_hideFindReplace).toInt();
+    m_smartClick = settings.value("m_smartClick", m_smartClick).toBool();
 	
 	if( !QDir().exists(m_includeDirectory) )
 	{
@@ -886,11 +931,12 @@ QString MainImpl::loadINI()
     actionEditor_mode->setChecked( settings.value("editorMode", actionEditor_mode->isChecked()).toBool() );
     settings.endGroup();
 
-    tabExplorer->setTabEnabled( 1, m_showTreeClasses );
+    /* TODO
     if (!m_showTreeClasses) //ToolsOptions/General
         tabExplorer->setTabToolTip( 1, tr("Classes explorer is disabled, please enable it in the Options dialog") );
     else
         tabExplorer->setTabToolTip( 1, "" );
+    */
     m_assistant->setdocumentationDirectory( m_documentationDirectory );
     // Load shortcuts
     settings.beginGroup("Shortcuts");
@@ -939,7 +985,6 @@ QString MainImpl::loadINI()
         setWindowState(windowState() | Qt::WindowFullScreen);
 #endif
     restoreState(settings.value("state", saveState()).toByteArray()); // Toolbar and DockWidget state.
-    tabExplorer->setCurrentIndex( settings.value("tabExplorer", 0).toInt() );
     settings.endGroup();
 
 	settings.beginGroup("editormode");
@@ -1066,10 +1111,10 @@ bool MainImpl::openProject(QString s)
     if ( m_completion )
         delete m_completion;
     m_completion = new InitCompletion (this, treeClasses);
-    QString includes;
-    includes = m_includeDirectory;
+    QStringList includes;
+    includes << m_includeDirectory;
 #ifdef WIN32
-    includes += "\" \"" + QDir::cleanPath( QFileInfo(m_qmakeName).absoluteDir().path()+"/../src" ) ;
+    includes << QDir::cleanPath( QFileInfo(m_qmakeName).absoluteDir().path()+"/../src" ) ;
 #endif
     m_completion->setCtagsCmdPath( ctagsName() );
     m_completion->setQtInclude( includes );
@@ -1188,10 +1233,6 @@ void MainImpl::slotHelpQtWord()
             className = word;
         if( !word.isEmpty() )
         	className = m_completion->classForFunction(className, word);
-        if ( className.isEmpty() && word.startsWith("Q") )
-        {
-        	className = word;
-       	}
     }
     m_assistant->showQtWord(className, word );
 }
@@ -1287,7 +1328,17 @@ Editor * MainImpl::openFile(QStringList locationsList, int numLine, bool silentM
     }
     else if ( Editor::shortFilename(s).section(".", -1, -1).toLower() == "ts" )
     {
-        QProcess::startDetached (m_linguistName, QStringList(s));
+        if (!QProcess::startDetached (m_linguistName, QStringList(s)))
+        {
+        	#ifdef Q_OS_MACX
+        	if (!QProcess::startDetached (m_linguistName + "/Contents/MacOS/Linguist", QStringList(s)))
+        	{
+        		// TODO: Error handling here
+       		}
+        	#else
+        	// TODO: Error handling here
+        	#endif
+       	}
         QApplication::restoreOverrideCursor();
         return 0;
     }
@@ -1326,6 +1377,7 @@ Editor * MainImpl::openFile(QStringList locationsList, int numLine, bool silentM
     editor->setTabSpaces( m_tabSpaces );
     editor->setAutoCompletion( m_autoCompletion );
     editor->setAutobrackets( m_autobrackets );
+    editor->setAutocomments( m_autocomments );
     editor->setBackgroundColor( m_backgroundColor );
     editor->setTextColor( m_textColor );
     editor->setMatch( m_match );
@@ -1333,6 +1385,7 @@ Editor * MainImpl::openFile(QStringList locationsList, int numLine, bool silentM
     editor->setMatchingColor( m_matchingColor );
     editor->setCurrentLineColor( m_currentLineColor );
     editor->setShowWhiteSpaces( m_displayWhiteSpaces );
+    editor->setRightMargin( m_rightMarginLine );
     editor->displayEditorToolbar( m_displayEditorToolbars );
     editor->setSyntaxColors
     (
@@ -1344,6 +1397,9 @@ Editor * MainImpl::openFile(QStringList locationsList, int numLine, bool silentM
         m_formatMethods,
         m_formatKeywords
     );
+    editor->setWordWrap(m_wordWrap);
+    editor->setHideFindReplace(m_hideFindReplace);
+    editor->smartClick = m_smartClick;
 
     if ( !editor->open(silentMode) )
     {
@@ -1360,7 +1416,7 @@ Editor * MainImpl::openFile(QStringList locationsList, int numLine, bool silentM
     connect(editor, SIGNAL(updateClasses(QString, QString)), this, SLOT(slotUpdateClasses(QString, QString)) );
     connect(editor, SIGNAL(otherFileChanged()), this, SLOT(slotUpdateOtherFileActions()));
     if ( m_debug )
-        connect(editor, SIGNAL(breakpoint(QString, bool, unsigned int, QString)), m_debug, SLOT(slotBreakpoint(QString, bool, unsigned int, QString)) );
+	    connect(editor, SIGNAL(breakpoint(QString, unsigned int, BlockUserData *)), m_debug, SLOT(slotBreakpoint(QString, unsigned int, BlockUserData *)) );
     setCurrentFile(s);
     slotCurrentTabChanged( m_tabEditors->currentIndex() );
     slotUpdateOtherFileActions();
@@ -1509,6 +1565,8 @@ void MainImpl::slotCompile(bool automaticCompilation)
 {
 	if( automaticCompilation && !m_automaticCompilation )
 		return;
+	if( !m_projectManager )
+		return;
     Editor *editor = currentEditor();
     if ( editor && Editor::suffixe( editor->filename() ).toLower() == "cpp" )
     {
@@ -1521,13 +1579,15 @@ void MainImpl::slotCompile(bool automaticCompilation)
     	{
         	m_buildingGroup->setEnabled( false );
 	        logBuild->clear();
-	        dockOutputs->setVisible(true);
+		dockBuild->show();
+		dockBuild->raise();
    		}
         if ( m_saveBeforeBuild && !automaticCompilation)
             slotSaveAll();
         if ( !automaticCompilation )
         {
-        	tabOutputs->setCurrentIndex( 0 );
+// 		// TODO should we raise the dockBuild ?
+//         	tabOutputs->setCurrentIndex( 0 );
 	        m_projectsDirectoriesList << editor->directory();
        	}
         QString projectDirectory = m_projectManager->fileDirectory(editor->filename() );
@@ -1553,7 +1613,7 @@ void MainImpl::slotCompile(bool automaticCompilation)
     }
 }
 //
-void MainImpl::slotBuild(bool clean, bool build, bool forceQmake)
+void MainImpl::slotBuild(bool clean, bool build, bool forceQmake, QString forceMode)
 {
     bool qmakeNeeded = false;
     if (!m_projectManager)
@@ -1568,6 +1628,7 @@ void MainImpl::slotBuild(bool clean, bool build, bool forceQmake)
     if ( actionDebug->text() == tr("Stop") && !slotDebug())
         return;
     m_buildAfterDebug = false;
+    if (forceMode.isEmpty()) forceMode = m_lastForcedMode;
     qmakeNeeded = m_projectManager->isModifiedProject();
     if ( m_projectsDirectoriesList.count() == 0 )
     {
@@ -1577,11 +1638,11 @@ void MainImpl::slotBuild(bool clean, bool build, bool forceQmake)
     	}
         m_buildingGroup->setEnabled( false );
         logBuild->clear();
-        dockOutputs->setVisible(true);
         if ( m_saveBeforeBuild )
             slotSaveAll();
-        tabOutputs->setCurrentIndex( 0 );
-        //
+	dockBuild->show();
+	dockBuild->raise();
+	//
         m_projectsDirectoriesList = m_projectManager->buildableProjectsDirectories();
         m_clean = clean;
         m_build = build;
@@ -1595,7 +1656,8 @@ void MainImpl::slotBuild(bool clean, bool build, bool forceQmake)
     {
         m_configureCompletionNeeded = true;
     }
-    m_builder = new Build(this, m_qmakeName, m_makeName, m_makeOptions, projectDirectory+"/"+projectName, qmakeNeeded|m_clean, m_clean, m_build);
+    m_builder = new Build(this, m_qmakeName, m_makeName, m_makeOptions, projectDirectory+"/"+projectName, 
+    	qmakeNeeded|m_clean, m_clean, m_build, QString(), forceMode);
 
     connect(logBuild, SIGNAL(incErrors()), m_builder, SLOT(slotIncErrors()) );
     connect(logBuild, SIGNAL(incWarnings()), m_builder, SLOT(slotIncWarnings()) );
@@ -1608,6 +1670,41 @@ void MainImpl::slotBuild(bool clean, bool build, bool forceQmake)
    	}
     m_builder->start();
 }
+
+void MainImpl::slotBuildRelease()
+{
+	if (actionRelease_mode->isChecked())
+	{
+		setQmakeForcedMode("release");
+		slotBuild(true, false, true, "release");
+	}
+	else
+	{
+		slotForgetBuildMode();
+	}
+}
+
+void MainImpl::slotBuildDebug()
+{
+	if (actionDebug_mode->isChecked())
+	{
+		setQmakeForcedMode("debug");
+		slotBuild(true, false, true, "debug");
+	}
+	else
+	{
+		slotForgetBuildMode();
+	}
+}
+
+void MainImpl::slotForgetBuildMode()
+{
+	if (!m_lastForcedMode.isEmpty())
+	{
+		setQmakeForcedMode("");
+		slotBuild(true, false, true);
+	}
+}
 //
 void MainImpl::slotStopBuild()
 {
@@ -1620,7 +1717,8 @@ void MainImpl::slotEndBuild()
 {
     if ( m_configureCompletionNeeded )
         configureCompletion(m_projectsDirectoriesList.first());
-    m_projectsDirectoriesList.removeFirst();
+    if ( m_projectsDirectoriesList.count() ) 
+        m_projectsDirectoriesList.removeFirst();
     if ( m_projectsDirectoriesList.count() )
         slotBuild();
     else
@@ -1860,8 +1958,8 @@ bool MainImpl::slotDebug(bool executeOnly)
     actionStopDebug->setEnabled( !executeOnly );
     logDebug->clear();
     registersImpl->registers(QString());
-    dockOutputs->setVisible(true);
-    tabOutputs->setCurrentIndex( 1 );
+    dockOutputs->show();
+    dockOutputs->raise();
     Parameters parameters = m_projectManager->parameters();
     if ( parameters.workingDirectory.isEmpty() )
         parameters.workingDirectory = m_projectManager->projectDirectoryOfExecutable();
@@ -2185,8 +2283,8 @@ void MainImpl::slotFindInFiles()
         m_findInFiles->setDefaultWord(editor->selection());
     }
 
-    dockOutputs->setVisible(true);
-    tabOutputs->setCurrentIndex( 4 );
+    dockFindInFiles->show();
+    dockFindInFiles->raise();
     m_findInFiles->show();
     // Not delete dialog to save options, location and pattern on next showing.
 }
@@ -2211,6 +2309,7 @@ void MainImpl::slotToolsControl(bool show)
     m_checkEnvironmentOnStartup = toolsControlImpl->checkEnvOnStartup();
     m_assistant->setName( toolsControlImpl->assistantName() );
     m_designer->setName( toolsControlImpl->designerName() );
+	m_assistant->setqVersion( toolsControlImpl->qVersion() );
     delete toolsControlImpl;
     treeClasses->setCtagsIsPresent( m_ctagsIsPresent );
     treeClasses->setCtagsName( m_ctagsName );
@@ -2305,12 +2404,12 @@ void MainImpl::loadPlugins()
 #else
     if ( m_pluginsDirectory.isEmpty() )
     {
-        QDir dir = QDir("/usr/lib/qdevelop/plugins");
+        QDir dir = QDir(qApp->applicationDirPath()+"/../lib/qdevelop/plugins/");
         foreach(QString fileName, dir.entryList(QDir::Files) )
         {
             entryList += dir.absoluteFilePath(fileName);
         }
-        dir = QDir("~/.qdevelop/plugins");
+	dir = QDir(QDir::homePath() + "/.qdevelop/plugins");
         foreach(QString fileName, dir.entryList(QDir::Files) )
         {
             entryList += dir.absoluteFilePath(fileName);
@@ -2411,10 +2510,10 @@ void MainImpl::checkQtDatabase()
     connect(m_buildQtDatabase, SIGNAL(finished()), m_buildQtDatabase, SLOT(deleteLater()) );
     connect(m_buildQtDatabase, SIGNAL(showMessage(QString)), this, SLOT(slotShowMessage(QString)) );
     connect(m_buildQtDatabase, SIGNAL(finished()), this, SLOT(slotBuildQtDatabaseEnded()) );
-    QString includes;
-    includes = m_includeDirectory;
+    QStringList includes;
+    includes << m_includeDirectory;
 #ifdef WIN32
-    includes += "\" \"" + QDir::cleanPath( QFileInfo(m_qmakeName).absoluteDir().path()+"/../src" ) ;
+    includes << QDir::cleanPath( QFileInfo(m_qmakeName).absoluteDir().path()+"/../src" ) ;
 #endif
     m_buildQtDatabase->setCtagsCmdPath( ctagsName() );
     m_buildQtDatabase->setQtInclude( includes );
@@ -2481,6 +2580,111 @@ void MainImpl::on_actionEditor_mode_triggered()
 	}
 }
 
+// set up the main window for "full view"
+// docks on the left, right and bottom, all tabified
+// tabs in the sides "win" over the bottom group, as I think
+// it looks better.
+void MainImpl::on_actionFullDocksView_triggered()
+{
+	setUpdatesEnabled( false );
+	blockSignals( true );
+
+	setCorner( Qt::TopLeftCorner, Qt::LeftDockWidgetArea );
+	setCorner( Qt::TopRightCorner, Qt::RightDockWidgetArea );
+	setCorner( Qt::BottomLeftCorner, Qt::LeftDockWidgetArea );
+	setCorner( Qt::BottomRightCorner, Qt::RightDockWidgetArea );
+	
+	addDockWidget( Qt::BottomDockWidgetArea, dockBuild  );
+	addDockWidget( Qt::BottomDockWidgetArea, dockOutputs );
+	addDockWidget( Qt::BottomDockWidgetArea, dockVariables );
+	addDockWidget( Qt::BottomDockWidgetArea, dockOtherVariables );
+	addDockWidget( Qt::BottomDockWidgetArea, dockFindInFiles );
+	addDockWidget( Qt::LeftDockWidgetArea  , dockFiles );
+	addDockWidget( Qt::LeftDockWidgetArea  , dockClasses );
+	addDockWidget( Qt::RightDockWidgetArea , dockCallsStack );
+	addDockWidget( Qt::RightDockWidgetArea , dockRegisters );
+	
+	// left docks
+	tabifyDockWidget( dockFiles, dockClasses );
+	// bottom docks
+	tabifyDockWidget( dockBuild, dockOutputs );
+	tabifyDockWidget( dockBuild, dockVariables );
+	tabifyDockWidget( dockBuild, dockOtherVariables );
+	tabifyDockWidget( dockBuild, dockFindInFiles );
+	// right docks
+	tabifyDockWidget( dockCallsStack, dockRegisters );
+
+	foreach( QDockWidget *dock, findChildren<QDockWidget *>() )
+	{
+		dock->setFloating( false );
+		dock->show();
+	}
+	
+	// raise the first tabs in each group
+	dockBuild->raise();
+	dockFiles->raise();
+	dockCallsStack->raise();
+	
+	// just in case :)
+	actionEditor_mode->setChecked( false );
+
+	blockSignals( false );
+	setUpdatesEnabled( true );
+}
+
+// this is my favorite display mode, it gets it's own method
+// and menu item :)
+void MainImpl::on_actionMinimalDocksView_triggered()
+{
+	setUpdatesEnabled( false );
+	blockSignals( true );
+	
+	setCorner( Qt::TopLeftCorner, Qt::LeftDockWidgetArea );
+	setCorner( Qt::TopRightCorner, Qt::RightDockWidgetArea );
+	setCorner( Qt::BottomLeftCorner, Qt::LeftDockWidgetArea );
+	setCorner( Qt::BottomRightCorner, Qt::RightDockWidgetArea );
+	
+	addDockWidget( Qt::BottomDockWidgetArea, dockBuild  );
+	addDockWidget( Qt::BottomDockWidgetArea, dockOutputs );
+	addDockWidget( Qt::BottomDockWidgetArea, dockVariables );
+	addDockWidget( Qt::BottomDockWidgetArea, dockOtherVariables );
+	addDockWidget( Qt::BottomDockWidgetArea, dockFindInFiles );
+	addDockWidget( Qt::LeftDockWidgetArea  , dockFiles );
+	addDockWidget( Qt::LeftDockWidgetArea  , dockClasses );
+	addDockWidget( Qt::RightDockWidgetArea , dockCallsStack );
+	addDockWidget( Qt::RightDockWidgetArea , dockRegisters );
+	
+	// left docks
+	splitDockWidget( dockFiles, dockClasses, Qt::Vertical );
+	// bottom docks
+	tabifyDockWidget( dockBuild, dockOutputs );
+	tabifyDockWidget( dockBuild, dockVariables );
+	tabifyDockWidget( dockBuild, dockOtherVariables );
+	tabifyDockWidget( dockBuild, dockFindInFiles );
+	// right docks
+	splitDockWidget( dockCallsStack, dockRegisters, Qt::Vertical );
+
+	foreach( QDockWidget *dock, findChildren<QDockWidget *>() )
+	{
+		dock->setFloating( false );
+		dock->hide();
+	}
+	
+	dockBuild->raise();
+	
+	// just in case :)
+	actionEditor_mode->setChecked( false );
+
+	// only visible docks in this mode
+	dockBuild->show();
+	dockOutputs->show();
+	dockFiles->show();
+	dockClasses->show();
+	
+	setUpdatesEnabled( true );
+	blockSignals( false );
+}
+
 void MainImpl::automaticCompilationState(Editor *editor, int state)
 {
 	if( state == 2 )
