@@ -7,7 +7,7 @@ public:
 	enum Action{ReplaceSelection, ReplaceAll, Append};
     virtual ~TextEditInterface() {}
 	virtual QString menuName() const = 0;
-    virtual QString text(QString text, QString selectedText) = 0;
+    virtual QString text(QString text, QString selectedText, QTextCodec *codec) = 0;
     virtual TextEditInterface::Action action() const = 0;
     virtual bool hasConfigDialog() const = 0;
     virtual void config() = 0;
