@@ -53,6 +53,7 @@
 #include <QProgressBar>
 #include <QPlastiqueStyle>
 #include <QSplashScreen>
+#define QD qDebug() << __FILE__ << __LINE__ << ":"
 //
 ProjectManager::ProjectManager(MainImpl * parent, TreeProject *treeFiles, TreeClasses *treeClasses)
         : m_parent(parent), m_treeFiles(treeFiles), m_treeClasses(treeClasses)
@@ -123,7 +124,7 @@ void ProjectManager::parseTreeClasses(bool force)
         return;
     m_treeClasses->clear();
     QString directory = projectDirectory( m_treeFiles->topLevelItem( 0 ) );
-    if ( QFile::exists( directory+"/qdevelop-settings.db" ) && !force)
+    if ( QFile::exists( directory + "/" + SETTINGS_FILE_NAME ) && !force)
     {
         m_treeClasses->fromDB( directory );
     }
@@ -264,9 +265,9 @@ void ProjectManager::saveProjectSettings()
 {
     // Save opened files
     QString directory = projectDirectory(m_treeFiles->topLevelItem(0));
-    if ( !connectDB( directory + "/qdevelop-settings.db" ) )
+    if ( !connectDB( directory + "/" + SETTINGS_FILE_NAME ) )
         return;
-    QSqlQuery query(QSqlDatabase::database( directory + "/qdevelop-settings.db") );
+    QSqlQuery query(QSqlDatabase::database( directory + "/" + SETTINGS_FILE_NAME) );
     QString queryString = "delete from editors where 1";
     if (!query.exec(queryString))
     {
@@ -303,7 +304,7 @@ void ProjectManager::saveProjectSettings()
         if ( editor )
         {
             QString filename = QDir( directory ).relativeFilePath( editor->filename() );
-            QSqlQuery query( QSqlDatabase::database( directory + "/qdevelop-settings.db" ));
+            QSqlQuery query( QSqlDatabase::database( directory + "/" + SETTINGS_FILE_NAME ));
             query.prepare("INSERT INTO editors (filename, scrollbar, numline) "
                           "VALUES (:filename, :scrollbar, :numline)");
             query.bindValue(":filename", filename);
@@ -314,7 +315,7 @@ void ProjectManager::saveProjectSettings()
             foreach(int line, editor->bookmarksList())
             {
                 filename = QDir( directory ).relativeFilePath( editor->filename() );
-	            QSqlQuery query( QSqlDatabase::database( directory + "/qdevelop-settings.db" ));
+	            QSqlQuery query( QSqlDatabase::database( directory + "/" + SETTINGS_FILE_NAME ));
                 query.prepare("INSERT INTO bookmarks (filename, numline) "
                               "VALUES (:filename, :numline)");
                 query.bindValue(":filename", filename);
@@ -326,7 +327,7 @@ void ProjectManager::saveProjectSettings()
             {
 		        BlockUserData *blockUserData = (BlockUserData*)block.userData();
                 filename = QDir( directory ).relativeFilePath( editor->filename() );
-	            QSqlQuery query( QSqlDatabase::database( directory + "/qdevelop-settings.db" ));
+	            QSqlQuery query( QSqlDatabase::database( directory + "/" + SETTINGS_FILE_NAME ));
                 query.prepare("INSERT INTO breakpoints (filename, numline, breakpointCondition, isTrue) "
                               "VALUES (:filename, :numline, :breakpointCondition, :isTrue)");
                 query.bindValue(":filename", filename);
@@ -349,7 +350,7 @@ void ProjectManager::saveProjectSettings()
         srcDir = QDir( projectDir ).relativeFilePath( srcDir );
         QString uiDir = uiDirectory( itemProject(projectName) );
         uiDir = QDir( projectDir ).relativeFilePath( uiDir );
-        QSqlQuery query( QSqlDatabase::database( directory + "/qdevelop-settings.db" ));
+        QSqlQuery query( QSqlDatabase::database( directory + "/" + SETTINGS_FILE_NAME ));
         query.prepare("INSERT INTO projectsDirectories (projectName, srcDirectory, uiDirectory) "
                       "VALUES (:projectName, :srcDirectory, :uiDirectory)");
         query.bindValue(":projectName", projectName);
@@ -359,12 +360,21 @@ void ProjectManager::saveProjectSettings()
             qDebug()<<"projectsDirectories" << query.lastError();
     }
     //
-    query.prepare("INSERT INTO config (currentEditor) "
-                  "VALUES (:currentEditor)");
+    query.prepare("INSERT INTO config (key, value) "
+                  "VALUES (:key, :value)");
+    query.bindValue(":key", "currentEditor");
     if ( m_parent->tabEditors()->count() )
-        query.bindValue(":currentEditor", m_parent->tabEditors()->currentIndex());
+        query.bindValue(":value", QString::number( m_parent->tabEditors()->currentIndex()) );
     else
-        query.bindValue(":currentEditor", -1);
+        query.bindValue(":value", "-1");
+    if ( !query.exec() )
+        qDebug()<<"config" << query.lastError();
+    query.bindValue(":key", "showAsKrawek");
+    query.bindValue(":value", QString::number( m_treeFiles->showAsKrawek() ) );
+    if ( !query.exec() )
+        qDebug()<<"config" << query.lastError();
+    query.bindValue(":key", "forceQmakeMode");
+    query.bindValue(":value", m_parent->qmakeForcedMode() );
     if ( !query.exec() )
         qDebug()<<"config" << query.lastError();
 }
@@ -373,9 +383,9 @@ void ProjectManager::loadProjectSettings()
 {
     // Save opened files
     QString directory = projectDirectory(m_treeFiles->topLevelItem(0));
-    if ( !connectDB( directory + "/qdevelop-settings.db" ) )
+    if ( !connectDB( directory + "/" + SETTINGS_FILE_NAME ) )
         return;
-    QSqlQuery query( QSqlDatabase::database( directory + "/qdevelop-settings.db" ));
+    QSqlQuery query( QSqlDatabase::database( directory + "/" + SETTINGS_FILE_NAME ));
     query.prepare("select * from editors where 1");
     query.exec();
     while (query.next())
@@ -422,9 +432,24 @@ void ProjectManager::loadProjectSettings()
     query.exec();
     while (query.next())
     {
-        int currentEditor = query.value( 0 ).toInt();
-        if ( currentEditor != -1 )
-            m_parent->tabEditors()->setCurrentIndex( currentEditor );
+        int currentEditor = -1;
+        QString key  = query.value( 0 ).toString();
+        if( key == "currentEditor" )
+        {
+        	currentEditor = query.value( 1 ).toString().toInt();
+	        if ( currentEditor != -1 )
+	            m_parent->tabEditors()->setCurrentIndex( currentEditor );
+       	}
+        else if( key == "showAsKrawek" )
+        {
+        	bool showAsKrawek = query.value( 1 ).toString().toInt();
+        	if( showAsKrawek )
+        		m_treeFiles->slotShowAsKrawek();
+       	}
+       	else if ( key == "forceQmakeMode" )
+       	{
+       		m_parent->setQmakeForcedMode(query.value( 1 ).toString());
+      	}
     }
     //
     query.prepare("select * from projectsDirectories where 1");
@@ -673,7 +698,7 @@ void ProjectManager::slotAddNewItem(QTreeWidgetItem *it, QString kind)
         if ( ajouter )
         {
             window->comboProjects->addItem( projectName,  addressToVariant(projectsList.at(nbProjects)));
-            if ( projectsList.at(nbProjects) == it )
+            if ( projectsList.at(nbProjects) == it || projectsList.at(nbProjects) == it->parent() )
                 window->comboProjects->setCurrentIndex( window->comboProjects->count()-1);
             QList<QTreeWidgetItem *> listeScope;
             childsList(projectsList.at(nbProjects), "SCOPE", listeScope);
@@ -713,7 +738,7 @@ void ProjectManager::slotAddNewItem(QTreeWidgetItem *it, QString kind)
     {
         QString line = window->filename->text();
         filesList = line.split(",");
-        repCreation = window->location->text();
+        repCreation = window->location->text().replace("\\", "/");
         variant = window->comboProjects->itemData( window->comboProjects->currentIndex() );
         delete window;
     }
@@ -724,12 +749,14 @@ void ProjectManager::slotAddNewItem(QTreeWidgetItem *it, QString kind)
     }
     QTreeWidgetItem *item = (QTreeWidgetItem*)variantToItem(variant);
     projectDir = projectDirectory( item );
+    QDir projectDirObj(projectDir);
     setQmake( projectFilename( item ) );
     foreach(QString filename, filesList)
     {
-        absoluteFilename = repCreation+"/"+filename.remove("\"").simplified();
-        QDir( projectDir ).mkdir( repCreation );
-        filename = QDir(projectDir).relativeFilePath(absoluteFilename).replace("\\", "/");
+        absoluteFilename = projectDirObj.absoluteFilePath(repCreation)+"/"+filename.remove("\"").simplified();
+        absoluteFilename = QDir::cleanPath(absoluteFilename);
+        projectDirObj.mkdir( repCreation );
+        filename = projectDirObj.relativeFilePath(absoluteFilename);
         QFile file ( absoluteFilename );
         if ( file.exists() )
         {
@@ -765,7 +792,7 @@ void ProjectManager::slotAddNewItem(QTreeWidgetItem *it, QString kind)
             else
                 return;
         }
-        else if ( filename.section(".", -1, -1) == "h" )
+        else if ( filename.section(".", -1, -1) == "h" || filename.section(".", -1, -1) == "hpp" )
         {
             // add a default content for *.h files
             QString defString = filename.toUpper().section("/", -1, -1);
@@ -862,7 +889,7 @@ void ProjectManager::insertFile(QTreeWidgetItem *it, QString filename, bool sile
     }
     else
     {
-        if ( !QString("ui|cpp|h|qrc|ts").contains( kindFile ) )
+        if ( !(QStringList() << "ui" << "cpp" << "h" << "hpp" << "qrc" << "ts").contains(kindFile) )
         {
             if ( !silentMode)
                 QMessageBox::warning(0,
@@ -878,7 +905,7 @@ void ProjectManager::insertFile(QTreeWidgetItem *it, QString filename, bool sile
         {
             parentKey = "SOURCES";
         }
-        else if ( kindFile == "h" )
+        else if ( kindFile == "h" || kindFile == "hpp" )
         {
             parentKey = "HEADERS";
 
@@ -908,7 +935,7 @@ void ProjectManager::insertFile(QTreeWidgetItem *it, QString filename, bool sile
         while ( (parent = parent->parent()) );
     }
     //
-    if ( kindFile == "cpp" || kindFile == "h")
+    if ( kindFile == "cpp" || kindFile == "h" || kindFile == "hpp")
     {
         QString projectDir = projectDirectory(newItem);
         QString absoluteName = QDir(projectDir+"/"+filename).absolutePath();
@@ -1205,11 +1232,11 @@ void ProjectManager::slotPreviewForm(QTreeWidgetItem *it)
     QFile file(uiName);
     file.open(QFile::ReadOnly);
     m_previewForm = builder.load(&file, 0);
-    m_previewForm->setWhatsThis( filename );
     file.close();
     //
     if ( m_previewForm )
     {
+    	m_previewForm->setWhatsThis( filename );
         // Set tooltip for all widgets in form
         QString name = m_previewForm->objectName();
         QString className = m_previewForm->metaObject()->className();
@@ -1246,7 +1273,7 @@ void ProjectManager::slotPreviewForm(QTreeWidgetItem *it)
     }
     else
     {
-        QString error = tr("The file  \"%1\" ").arg(uiName);
+        QString error = tr("File not found: \"%1\"").arg(uiName);
         QMessageBox::warning(0,
                              "QDevelop", error,
                              tr("Cancel") );
@@ -1263,6 +1290,13 @@ void ProjectManager::slotSubclassing(QTreeWidgetItem *it)
     QStringList listeHeaders;
     headers( itemProject(projectName), listeHeaders);
     SubclassingImpl *dialog = new SubclassingImpl(0, m_parent, srcDir, uiName, listeHeaders);
+    if (!dialog->isValid())
+    {
+    	QString error = tr("File not found: \"%1\"").arg(uiName);
+        QMessageBox::warning(0, "QDevelop", error, tr("Cancel") );
+    	delete dialog;
+    	return;
+   	}
     if ( dialog->exec() == QDialog::Accepted )
     {
         while ( toKey( it->data(0, Qt::UserRole) ) != "PROJECT" )
@@ -1619,6 +1653,10 @@ QTreeWidgetItem * ProjectManager::insertItem(QTreeWidgetItem *parent, QString ke
         it->setText(0, begin + tr("Resources"));
         it->setIcon(0, QIcon(":/treeview/images/qrc.png"));
     }
+    else
+    {
+	    it->setToolTip(0, data);
+   	}
     QTreeWidgetItem *itemParent = it->parent();
     bool hide = true;
     for (int i = 0; i < itemParent->childCount(); i++ )
@@ -2009,7 +2047,11 @@ QString ProjectManager::executableName(QString preferedVersion)
             QString realVersion = projectVersion( it );
             if ( realVersion.toLower() == "debug_and_release" )
                 realVersion = preferedVersion;
-            else if ( realVersion != preferedVersion && realVersion.length() )
+            else if (!m_parent->qmakeForcedMode().isEmpty())
+            {
+            	realVersion = m_parent->qmakeForcedMode();
+           	}
+            if ( realVersion != preferedVersion && realVersion.length() )
             {
                 QMessageBox::warning(0,
                                      "QDevelop", tr("The only available version for \"%1\" is %2").arg(projectName, realVersion),
@@ -2029,6 +2071,7 @@ QString ProjectManager::executableName(QString preferedVersion)
     }
     if ( m_executablesList.count() == 1 )
     {
+QD;
         QString choice = m_executablesList.first();
         m_executablesList.clear();
         m_projectDirectoryOfExecutable = m_projectDirectoryOfExecutableList.first();
@@ -2169,14 +2212,15 @@ QString ProjectManager::findExecutable( QString projectDirectory, QString prefer
     QFile makefile(projectDirectory+"/"+"Makefile");
     if (!makefile.open(QIODevice::ReadOnly | QIODevice::Text))
         return QString();
-    while (!makefile.atEnd())
+	QTextStream *makefileText = new QTextStream(&makefile);
+    while (!makefileText->atEnd())
     {
-        line = QString( makefile.readLine() );
-        // Partie concernant le file Makefile appelant sous Windows Makefile.Debug ou Makefile.Release.
-        // Sans objet sous Linux
+        line = QString( makefileText->readLine() );
+        // Here the file Makefile call under Windows (only) Makefile.Debug or Makefile.Release.
         if ( line.contains(" ") && line.section(" ", 0, 0).simplified() == "first:" && (line.section(" ", 1, 1).simplified()=="all" ))
             cible = preferedVersion+"-all";
-        else if ( line.contains(" ") && line.section(" ", 0, 0).simplified() == "first:" && (line.section(" ", 1, 1).simplified()=="debug" || line.section(" ", 1, 1).simplified()=="release"))
+        else if ( line.contains(" ") && line.section(" ", 0, 0).simplified() == "first:" 
+        	&& (line.section(" ", 1, 1).simplified()=="debug" || line.section(" ", 1, 1).simplified()=="release"))
             cible = line.section(" ", 1, 1).simplified();
         if ( line.contains("=") && line.section("=", 0, 0).simplified() == "MAKEFILE" )
             fichierMakefile = line.section("=", 1, 1).simplified();
@@ -2185,12 +2229,14 @@ QString ProjectManager::findExecutable( QString projectDirectory, QString prefer
             fichierMakefile = line.section(" ", 1, 1).simplified().replace("$(MAKEFILE)", fichierMakefile);
             makefile.close();
             makefile.setFileName( projectDirectory+"/"+fichierMakefile );
+			delete makefileText;
             if (!makefile.open(QIODevice::ReadOnly | QIODevice::Text))
                 return QString();
             cible = QString();
+			makefileText = new QTextStream(&makefile);
             continue;
         }
-        // Partie commune Win et Linux
+        // Part for Win and Linux
         // TARGET is the good variable to find exe on Linux
         if ( line.contains("=") && line.section("=", 0, 0).simplified() == "TARGET" )
         {
@@ -2198,7 +2244,8 @@ QString ProjectManager::findExecutable( QString projectDirectory, QString prefer
             int pos = exe.indexOf("#");
             if ( pos > -1 )
                 exe = exe.left(pos);
-            exe = QDir::cleanPath(projectDirectory + "/" + exe );
+            exe = exe.replace("\\ ", " ");
+            exe = QDir::cleanPath(projectDirectory + "/" + exe ).remove("\"");
             if ( !QString("so:dll:a").contains(exe.section(".", -1, -1).toLower() ) && QDir().exists(exe) )
                 exeName = exe;
         }
@@ -2209,12 +2256,14 @@ QString ProjectManager::findExecutable( QString projectDirectory, QString prefer
             int pos = exe.indexOf("#");
             if ( pos > -1 )
                 exe = exe.left(pos);
-            exe = QDir::cleanPath(projectDirectory + "/" + exe );
+            exe = exe.replace("\\ ", " ");
+            exe = QDir::cleanPath(projectDirectory + "/" + exe ).remove("\"");
             if ( !QString("so:dll:a").contains(exe.section(".", -1, -1).toLower() ) && QDir().exists(exe) )
                 exeName = exe;
         }
     }
     makefile.close();
+	delete makefileText;
     return exeName;
 }
 //
