@@ -132,6 +132,7 @@ void ProjectPropertieImpl::connections()
     connect(dll, SIGNAL(toggled(bool)), this, SLOT(slotCheck(bool)) );
     connect(exceptions, SIGNAL(toggled(bool)), this, SLOT(slotCheck(bool)) );
     connect(lib_bundle, SIGNAL(toggled(bool)), this, SLOT(slotCheck(bool)) );
+    connect(link_pkgconfig, SIGNAL(toggled(bool)), this, SLOT(slotCheck(bool)) );
     connect(no_lflags_merge, SIGNAL(toggled(bool)), this, SLOT(slotCheck(bool)) );
     connect(opengl, SIGNAL(toggled(bool)), this, SLOT(slotCheck(bool)) );
     connect(plugin, SIGNAL(toggled(bool)), this, SLOT(slotCheck(bool)) );
@@ -161,6 +162,10 @@ void ProjectPropertieImpl::connections()
     connect(app, SIGNAL(toggled(bool)), this, SLOT(slotCheck(bool)) );
     connect(lib, SIGNAL(toggled(bool)), this, SLOT(slotCheck(bool)) );
     connect(subdirs, SIGNAL(toggled(bool)), this, SLOT(slotCheck(bool)) );
+    connect(webkit, SIGNAL(toggled(bool)), this, SLOT(slotCheck(bool)) );
+    connect(phonon, SIGNAL(toggled(bool)), this, SLOT(slotCheck(bool)) );
+    connect(xmlpatterns, SIGNAL(toggled(bool)), this, SLOT(slotCheck(bool)) );
+    connect(script, SIGNAL(toggled(bool)), this, SLOT(slotCheck(bool)) );
     //
     connect(srcDirectoryButton, SIGNAL(clicked()), this, SLOT(slotSrcDirectory()) );
     connect(uiDirectoryButton, SIGNAL(clicked()), this, SLOT(slotUiDirectory()) );
@@ -192,6 +197,7 @@ void ProjectPropertieImpl::unconnections()
     disconnect(dll, SIGNAL(toggled(bool)), this, SLOT(slotCheck(bool)) );
     disconnect(exceptions, SIGNAL(toggled(bool)), this, SLOT(slotCheck(bool)) );
     disconnect(lib_bundle, SIGNAL(toggled(bool)), this, SLOT(slotCheck(bool)) );
+    disconnect(link_pkgconfig, SIGNAL(toggled(bool)), this, SLOT(slotCheck(bool)) );
     disconnect(no_lflags_merge, SIGNAL(toggled(bool)), this, SLOT(slotCheck(bool)) );
     disconnect(opengl, SIGNAL(toggled(bool)), this, SLOT(slotCheck(bool)) );
     disconnect(plugin, SIGNAL(toggled(bool)), this, SLOT(slotCheck(bool)) );
@@ -221,6 +227,10 @@ void ProjectPropertieImpl::unconnections()
     disconnect(app, SIGNAL(toggled(bool)), this, SLOT(slotCheck(bool)) );
     disconnect(lib, SIGNAL(toggled(bool)), this, SLOT(slotCheck(bool)) );
     disconnect(subdirs, SIGNAL(toggled(bool)), this, SLOT(slotCheck(bool)) );
+    disconnect(webkit, SIGNAL(toggled(bool)), this, SLOT(slotCheck(bool)) );
+    disconnect(phonon, SIGNAL(toggled(bool)), this, SLOT(slotCheck(bool)) );
+    disconnect(xmlpatterns, SIGNAL(toggled(bool)), this, SLOT(slotCheck(bool)) );
+    disconnect(script, SIGNAL(toggled(bool)), this, SLOT(slotCheck(bool)) );
 }
 //
 void ProjectPropertieImpl::slotCheck(bool activer)
@@ -247,7 +257,7 @@ void ProjectPropertieImpl::slotCheck(bool activer)
         }
         it = itTemplate;
     }
-    else if ( QString(":core:gui:network:libopengl:sql:svg:xml:qt3support:").contains( ":"+nomVariable+":" ) )
+    else if ( QString(":core:gui:network:libopengl:sql:svg:xml:qt3support:webkit:phonon:xmlpatterns:script:").contains( ":"+nomVariable+":" ) )
     {
         if (nomVariable == "libopengl") nomVariable = "opengl"; // There's both CONFIG += opengl and QT += opengl - the latter widget is called libopengl so the name must be manually replaced here
         QTreeWidgetItem *itQT = subItQT( itCombo );
@@ -412,11 +422,19 @@ void ProjectPropertieImpl::slotAddVariable()
     bool ok = newVariable->exec();
     if (ok)
     {
-        if ( ui.groupUserVariable->isChecked() && !ui.userVariable->text().isEmpty() )
-            nouvelleVariable = ui.userVariable->text();
-        else if ( !ui.groupUserVariable->isChecked() )
+    	if ( !ui.groupUserVariable->isChecked() )
             nouvelleVariable = ui.comboVariables->itemData(ui.comboVariables->currentIndex(), Qt::UserRole).toString();
-        else
+        else if( (QStringList() << "TEMPLATE" << "CONFIG" << "QT").contains(ui.userVariable->text()) )
+    	{
+            QMessageBox::warning(0, "QDevelop",
+	            tr("A new variable can not be \"QT\", \"CONFIG\" or \"TEMPLATE\""),
+	            tr("Cancel") );
+            delete newVariable;
+    		return;
+   		}
+        else if ( ui.groupUserVariable->isChecked() && !ui.userVariable->text().isEmpty() )
+            nouvelleVariable = ui.userVariable->text();
+        else 
         {
             delete newVariable;
             return;
@@ -613,6 +631,7 @@ void ProjectPropertieImpl::parseConfig(QTreeWidgetItem *it)
         else if ( donnee == "dll" )	dll->setChecked(true);
         else if ( donnee == "exceptions" )	exceptions->setChecked(true);
         else if ( donnee == "lib_bundle" )	lib_bundle->setChecked(true);
+        else if ( donnee == "link_pkgconfig" )	link_pkgconfig->setChecked(true);
         else if ( donnee == "no_lflags_merge" )	no_lflags_merge->setChecked(true);
         else if ( donnee == "opengl" )	opengl->setChecked(true);
         else if ( donnee == "plugin" ) plugin->setChecked(true);
@@ -654,6 +673,10 @@ void ProjectPropertieImpl::parseQT(QTreeWidgetItem *it)
         if ( donnee == "opengl" )	libopengl->setChecked(true);
         if ( donnee == "svg" )	svg->setChecked(true);
         if ( donnee == "qt3support" )	qt3support->setChecked(true);
+        if ( donnee == "webkit" )	webkit->setChecked(true);
+        if ( donnee == "phonon" )	phonon->setChecked(true);
+        if ( donnee == "xmlpatterns" )	xmlpatterns->setChecked(true);
+        if ( donnee == "script" )	script->setChecked(true);
     }
 }
 //
