@@ -118,7 +118,8 @@ TextEdit::TextEdit(Editor * parent, MainImpl *mainimpl, InitCompletion *completi
     m_tabPixmap		= QPixmap( tabPixmap_img ); 
 	m_spacePixmap		= QPixmap( spacePixmap_img ); 
 	m_showWhiteSpaces	= true;
-
+	m_rightMarginColumn	= 80;
+	m_autocomments = false;
     
     connect(document(), SIGNAL(modificationChanged(bool)), this, SIGNAL(editorModified(bool)));
     connect( this, SIGNAL( cursorPositionChanged() ), this, SLOT( slotCursorPositionChanged()));
@@ -202,16 +203,11 @@ void TextEdit::printWhiteSpacesAndMatching( QPainter &p )
 			{
 				QTextCursor cursor = textCursor();
 				cursor.setPosition( block.position() + i, QTextCursor::MoveAnchor);
+				QRect r1 = cursorRect( cursor );
+				cursor.movePosition( QTextCursor::Right, QTextCursor::MoveAnchor, 1);
 				QRect r2 = cursorRect( cursor );
-				if( QString("({[").contains( m_plainText.at( block.position() + i ) ) )
-					r2.adjust(r2.width()/3, r2.height()-1, r2.width()/3, 0);
-				else
-					r2.adjust(r2.width()/4, r2.height()-1, r2.width()/4, 0);
-				r2.adjust(2, 0, -2, 0);
-				p.setPen( m_matchingColor );
-				//int x = r2.x() + 4;
-				//int y = r2.y();// + fm.height();// / 2 - 5;
-				p.drawRect(r2);
+				p.setPen( QPen(m_matchingColor, 2) );
+				p.drawLine( r1.x()+r1.width()/2, r1.y()+r1.height()-2, r2.x()+r2.width()/2, r2.y()+r2.height()-2);
 			}
 			
 			if( m_showWhiteSpaces )
@@ -308,9 +304,7 @@ void TextEdit::slotCompletionList(TagList tagList )
         }
         m_completionList->setSelectionMode( QAbstractItemView::SingleSelection );
         QPalette palette;
-        QBrush brush(QColor(255, 255, 255, 255));
-        brush.setStyle(Qt::SolidPattern);
-        palette.setBrush(QPalette::Active, QPalette::Base, brush);
+        palette.setBrush(QPalette::Active, QPalette::Base, m_backgroundColor);
         m_completionList->setPalette(palette);
         w = qMin(w+20, 550);
         w = qMax(w, 150);
@@ -319,13 +313,13 @@ void TextEdit::slotCompletionList(TagList tagList )
             //posX = width()-220;
         if ( cursorRect().y() > viewport()->height()/2 )
         {
-            h = qMin( qMin(h+20, cursorRect().y()), 250);
+            h = qMin( qMin(h+20, cursorRect().y()), 500);
             m_completionList->setGeometry(posX, cursorRect().y()-h, w, h);
 
         }
         else
         {
-            h = qMin( qMin(h+20, viewport()->height()-22-cursorRect().y()), 250);
+            h = qMin( qMin(h+20, viewport()->height()-22-cursorRect().y()), 500);
             m_completionList->setGeometry(posX, cursorRect().y()+fontMetrics().height(), w, h);
 
         }
@@ -366,9 +360,7 @@ void TextEdit::slotCompletionHelpList(TagList tagList)
         }
         m_completionList->setSelectionMode( QAbstractItemView::NoSelection );
         QPalette palette;
-        QBrush brush(QColor(255, 255, 127, 255));
-        brush.setStyle(Qt::SolidPattern);
-        palette.setBrush(QPalette::Active, QPalette::Base, brush);
+        palette.setBrush(QPalette::Active, QPalette::Base, m_backgroundColor);
         m_completionList->setPalette(palette);
         w = qMin(w+20, 550);
         w = qMax(w, 150);
@@ -404,6 +396,17 @@ void TextEdit::mousePressEvent ( QMouseEvent * event )
 {
     m_completionList->hide();
     QTextEdit::mousePressEvent ( event );
+    if (m_editor->smartClick)
+    {
+    	if (event->modifiers() == Qt::ControlModifier)
+	    {
+	    	slotGotoImplementation();
+	   	}
+	   	else if (event->modifiers() == Qt::MetaModifier)
+	   	{
+	   		slotGotoDeclaration();
+	  	}
+   	}
 }
 //
 TextEdit::~TextEdit()
@@ -423,7 +426,7 @@ void TextEdit::setTabStopWidth(int taille)
 //
 bool TextEdit::open(bool silentMode, QString filename, QDateTime &lastModified)
 {
-    if ( cpphighlighter && !QString(":c:cc:cpp:h:hpp").contains( ":"+filename.section(".", -1, -1).toLower()+":" ) )
+    if ( cpphighlighter && !QString(":c:cc:cpp:h:hpp:").contains( ":"+filename.section(".", -1, -1).toLower()+":" ) )
     {
         delete cpphighlighter;
         cpphighlighter = 0;
@@ -484,6 +487,23 @@ void TextEdit::autobrackets()
     cursor.movePosition(QTextCursor::EndOfLine );
     setTextCursor( cursor );
 }
+// Divius: comments autoclose
+void TextEdit::autocomments(bool start)
+{
+	if (start)
+	{
+		textCursor().insertText( " * \n */" );
+		
+		setTextCursor( getLineCursor(currentLineNumber()-1) );
+		QTextCursor cursor = textCursor();
+		cursor.movePosition(QTextCursor::EndOfLine );
+		setTextCursor( cursor );
+	}
+	else
+	{
+		textCursor().insertText( "* " );
+	}
+}
 //
 void TextEdit::autoIndent()
 {
@@ -517,10 +537,10 @@ void TextEdit::autoIndent()
             break;
     }
     if ( simple.simplified().length() && ((simple.contains("(") && simple.contains(")")
-                                           && QString("if:while:do:switch:foreach").contains( simple.section("(", 0, 0).simplified() )
-                                           && (simple.contains('{') || simple.right(1) != ";" ) )
-                                          || QString("else:case:default").indexOf( simple.simplified() ) == 0
-                                          || simple.simplified().at(0) == '{' || simple.simplified().at( simple.simplified().length()-1 ) == '{' ))
+            && QString("if:while:do:switch:foreach").contains( simple.section("(", 0, 0).simplified() )
+            && (simple.contains('{') || simple.right(1) != ";" ) )
+           || QString("else:case:default").indexOf( simple.simplified() ) == 0
+           || simple.simplified().at(0) == '{' || simple.simplified().at( simple.simplified().length()-1 ) == '{' ))
     {
         if ( m_tabSpaces )
         {
@@ -550,7 +570,7 @@ void TextEdit::comment(ActionComment action)
 	if ( startPos != endPos && cursor.atBlockStart()) {
 		endBlock = document()->findBlock(endPos).previous();
 	}
-	
+
 	int firstLine = lineNumber( startBlock );
     int lastLine = lineNumber( endBlock );
     QTextBlock block = startBlock;
@@ -561,8 +581,9 @@ void TextEdit::comment(ActionComment action)
         QString text = block.text();
         if (!text.isEmpty()) {
 	        int i = 0;
-	        while (i < text.length() && text.at(i).isSpace())
+	        while (i < text.length() && (text.at(i).isSpace()))
 	            i++;
+
 	        if (action == Comment)
 	        {
 	            if (text.mid(i, 2) != "//")
@@ -580,11 +601,17 @@ void TextEdit::comment(ActionComment action)
 	            else
 	                text.insert(i, "//");
 	        }
-	        cursor.movePosition(QTextCursor::StartOfLine, QTextCursor::MoveAnchor);
-	        cursor.movePosition(QTextCursor::EndOfLine, QTextCursor::KeepAnchor);
+	        cursor.movePosition(QTextCursor::StartOfBlock, QTextCursor::MoveAnchor);
+	        cursor.movePosition(QTextCursor::EndOfBlock, QTextCursor::KeepAnchor);
+	        cursor.select(QTextCursor::BlockUnderCursor);
+	        qWarning() << cursor.selectedText();
+	        cursor.removeSelectedText();
+	        text.prepend("\n");
 	        cursor.insertText(text);
 		}
-        cursor.movePosition(QTextCursor::NextBlock);
+		if( !cursor.movePosition(QTextCursor::NextBlock) ) {
+			break;
+		}
         block = cursor.block();
     }
 	cursor.endEditBlock();
@@ -892,12 +919,12 @@ void TextEdit::gotoMatchingBracket()
     }
 }
 //
-void TextEdit::slotFind(Ui::FindWidget ui, QString ttf,QTextDocument::FindFlags options, bool fromButton)
+void TextEdit::slotFind(Ui::FindWidget uiFind, Ui::ReplaceWidget uiReplace, QString ttf,QTextDocument::FindFlags options, bool fromButton)
 {
     QTextDocument *doc = document();
-    QString oldText = ui.editFind->text();
+    QString oldText = uiFind.editFind->text();
     QTextCursor c = textCursor();
-    QPalette p = ui.editFind->palette();
+    QPalette p = uiFind.editFind->palette();
     p.setColor(QPalette::Active, QPalette::Base, Qt::white);
 
     if (c.hasSelection())
@@ -914,7 +941,8 @@ void TextEdit::slotFind(Ui::FindWidget ui, QString ttf,QTextDocument::FindFlags
     if (!ttf.isEmpty())
     {
         newCursor = doc->find(ttf, c, options);
-        ui.labelWrapped->hide();
+        uiFind.labelWrapped->hide();
+        uiReplace.labelWrapped->hide();
 
         if (newCursor.isNull())
         {
@@ -928,12 +956,15 @@ void TextEdit::slotFind(Ui::FindWidget ui, QString ttf,QTextDocument::FindFlags
                 newCursor = c;
             }
             else
-                ui.labelWrapped->show();
+            {
+                uiFind.labelWrapped->show();
+                uiReplace.reached->setText(tr("Reached end of page, continued from top"));
+                uiReplace.labelWrapped->show();
+           	}
         }
     }
-
     setTextCursor(newCursor);
-    ui.editFind->setPalette(p);
+    uiFind.editFind->setPalette(p);
 }
 //
 void TextEdit::paintEvent ( QPaintEvent * event )
@@ -949,7 +980,17 @@ void TextEdit::paintEvent ( QPaintEvent * event )
 
 	if (m_showWhiteSpaces || m_matchingBegin != -1)
 		printWhiteSpacesAndMatching( painter );
-		
+
+	if (m_rightMarginColumn > 0)
+	{
+		int x = m_rightMarginColumn * painter.fontMetrics().maxWidth()
+		  - horizontalScrollBar()->value();
+		QLine l = QLine( x, 0, x, viewport()->height() );
+		painter.setPen( Qt::black );
+		painter.drawLine( l );
+	}
+
+	painter.end();
     QTextEdit::paintEvent( event );
 }
 //
@@ -985,7 +1026,7 @@ void TextEdit::match()
     int pos = cursor.position();
    	m_matchingBegin = -1;
    	m_matchingEnd = -1;
-    if( pos==-1 || !QString("({[]})").contains( m_plainText.at( pos ) ) )
+    if( pos==-1 || pos >= m_plainText.size() || !QString("({[]})").contains( m_plainText.at( pos ) ) )
     	return;
     QChar car;
     if ( pos != -1 )
@@ -1167,6 +1208,35 @@ void TextEdit::keyPressEvent ( QKeyEvent * event )
         {
             QTextEdit::keyPressEvent ( event );
         }
+        // Divius: comments autoclose
+        if (m_autocomments)
+        {
+	        QTextBlock commentBlock = getLineCursor(currentLineNumber()-1).block();
+	        QString prevLine = commentBlock.text();
+	        if (prevLine.endsWith("/*") || prevLine.endsWith("/**") || prevLine.endsWith("/*!"))
+	        {
+	            autocomments(true);
+	       	}
+	       	else if (prevLine.simplified().startsWith("*") && !prevLine.simplified().startsWith("*/")) 
+	       		while (commentBlock.isValid())
+		       	{
+		       		prevLine = commentBlock.text();
+		       		if (prevLine.simplified().startsWith("/*"))
+		       		{
+		       			autocomments(false);
+		       			break;
+		      		}
+		      		else if (prevLine.simplified().startsWith("*") && !prevLine.simplified().startsWith("*/"))
+		      		{
+		      			commentBlock = commentBlock.previous();
+	      			}
+	      			else
+	      			{
+	      				break;
+	     			}
+		      	}
+       	}
+        //
     }
     else if ( event->key() == Qt::Key_Home && ( !event->modifiers() || event->modifiers() == Qt::ShiftModifier ) )
     {
@@ -1192,26 +1262,6 @@ void TextEdit::keyPressEvent ( QKeyEvent * event )
     {
         QTextEdit::keyPressEvent ( event );
     }
-    else if ( QKeySequence(event->key() | event->modifiers()) == m_mainImpl->shortcutCut() )
-    {
-        cut();
-    }
-    else if ( QKeySequence(event->key() | event->modifiers()) == m_mainImpl->shortcutPaste() )
-    {
-        paste();
-    }
-    else if ( QKeySequence(event->key() | event->modifiers()) == m_mainImpl->shortcutUndo() )
-    {
-        QTextCursor cursor = textCursor();
-        document()->undo(&cursor);
-        setTextCursor(cursor);
-    }
-    else if ( QKeySequence(event->key() | event->modifiers()) == m_mainImpl->shortcutRedo() )
-    {
-        QTextCursor cursor = textCursor();
-        document()->redo(&cursor);
-        setTextCursor(cursor);
-    }
     else if ((event->key() == Qt::Key_Down) && (QApplication::keyboardModifiers().testFlag(Qt::ControlModifier)))
     {
         verticalScrollBar()->triggerAction( QAbstractSlider::SliderSingleStepAdd );
@@ -1272,7 +1322,9 @@ void TextEdit::textPlugin(TextEditInterface *iTextEdit)
 {
     QApplication::setOverrideCursor(Qt::WaitCursor);
     QTextCursor cursor = textCursor();
-    QString s = iTextEdit->text(m_plainText, cursor.selection().toPlainText());
+    int mib = m_mainImpl->mibCodec();
+    QTextCodec *codec = QTextCodec::codecForMib(mib);
+    QString s = iTextEdit->text(m_plainText, cursor.selection().toPlainText(), codec);
     if (s.isEmpty())
     {
         QApplication::restoreOverrideCursor();
@@ -1310,7 +1362,7 @@ void TextEdit::dropEvent( QDropEvent * event )
         setTextCursor( save );
     }
     QTextEdit::dropEvent( event );
-    if ( event->keyboardModifiers() == Qt::NoModifier )
+    if ( event->dropAction() == Qt::CopyAction )
     {
         QTextCursor cursor = textCursor();
         int pos = textCursor().position();
@@ -1506,6 +1558,28 @@ QString TextEdit::wordUnderCursor(const QPoint & pos, bool select)
     return word;
 }
 //
+QString TextEdit::firstWordUnderCursor()
+{
+    QTextCursor save(textCursor());
+    QTextCursor cursor;
+    cursor = textCursor();
+    //
+    int curpos = cursor.position();
+    while ( curpos>0  && !QString(";").contains( m_plainText.at( curpos-1 ).toUpper()  ) )
+        curpos--;
+    while ( curpos < m_plainText.length()  && !QString("ABCDEFGHIJKLMNOPQRSTUVWXYZ0123456789_").contains( m_plainText.at( curpos ).toUpper()  ) )
+        curpos++;
+    cursor.setPosition(curpos, QTextCursor::MoveAnchor);
+    setTextCursor( cursor );
+    //
+    while ( curpos < m_plainText.length()  && QString("ABCDEFGHIJKLMNOPQRSTUVWXYZ0123456789_").contains( m_plainText.at( curpos ).toUpper()  ) )
+        curpos++;
+    cursor.setPosition(curpos, QTextCursor::KeepAnchor);
+    QString word = cursor.selectedText().simplified();
+    //
+    setTextCursor( save );
+    return word;
+}
 QString TextEdit::wordUnderCursor(const QString text)
 {
     int begin = text.length();
@@ -1527,6 +1601,24 @@ QString TextEdit::classNameUnderCursor(const QPoint & pos, bool addThis)
     else
         cursor = cursorForPosition ( pos );
     QString c = m_plainText.left(cursor.position());
+    for(int i=c.length()-1; i>=0; i--)
+    {
+    	if( c.at(i) == '.' )
+    	{
+    		c = c.left(i) + "." + m_editor->wordUnderCursor();
+    		break;
+   		}
+    	else if( c.mid(i, 2) == "->" )
+    	{
+    		c = c.left(i) + "->" + m_editor->wordUnderCursor();
+    		break;
+   		}
+    	else if( c.mid(i, 2) == "::" )
+    	{
+    		c = c.left(i) + "::";
+    		break;
+   		}
+   	}
     QString classname = m_completion->className(c);
     if ( classname.isEmpty() && addThis )
     {
@@ -1778,3 +1870,4 @@ QString TextEdit::tempFilename()
 	return m_editor->filename().section(".cpp", 0, 0) + "-qdeveloptmp.cpp";
 }
 
+
